==> kubernetes-model-1.0.54-sources.jar: io/fabric8/openshift/api/model/SignatureSubjectBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class SignatureSubjectBuilder extends SignatureSubjectFluentImpl<SignatureSubjectBuilder> implements VisitableBuilder<SignatureSubject,SignatureSubjectBuilder>{

    SignatureSubjectFluent<?> fluent;
    Boolean validationEnabled;

    public SignatureSubjectBuilder(){
            this(true);
    }
    public SignatureSubjectBuilder(Boolean validationEnabled){
            this(new SignatureSubject(), validationEnabled);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent){
            this(fluent, true);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SignatureSubject(), validationEnabled);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,SignatureSubject instance){
            this(fluent, instance, true);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,SignatureSubject instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommonName(instance.getCommonName()); 
            fluent.withOrganization(instance.getOrganization()); 
            fluent.withPublicKeyID(instance.getPublicKeyID()); 
            this.validationEnabled = validationEnabled; 
    }
    public SignatureSubjectBuilder(SignatureSubject instance){
            this(instance,true);
    }
    public SignatureSubjectBuilder(SignatureSubject instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.withPublicKeyID(instance.getPublicKeyID()); 
            this.validationEnabled = validationEnabled; 
    }

    public SignatureSubject build(){
            SignatureSubject buildable = new SignatureSubject(fluent.getCommonName(),fluent.getOrganization(),fluent.getPublicKeyID());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureSubjectBuilder that = (SignatureSubjectBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/SignatureSubjectBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class SignatureSubjectBuilder extends SignatureSubjectFluentImpl<SignatureSubjectBuilder> implements VisitableBuilder<SignatureSubject,SignatureSubjectBuilder>{

    SignatureSubjectFluent<?> fluent;
    Boolean validationEnabled;

    public SignatureSubjectBuilder(){
            this(true);
    }
    public SignatureSubjectBuilder(Boolean validationEnabled){
            this(new SignatureSubject(), validationEnabled);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent){
            this(fluent, true);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SignatureSubject(), validationEnabled);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,SignatureSubject instance){
            this(fluent, instance, true);
    }
    public SignatureSubjectBuilder(SignatureSubjectFluent<?> fluent,SignatureSubject instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommonName(instance.getCommonName()); 
            fluent.withOrganization(instance.getOrganization()); 
            fluent.withPublicKeyID(instance.getPublicKeyID()); 
            this.validationEnabled = validationEnabled; 
    }
    public SignatureSubjectBuilder(SignatureSubject instance){
            this(instance,true);
    }
    public SignatureSubjectBuilder(SignatureSubject instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.withPublicKeyID(instance.getPublicKeyID()); 
            this.validationEnabled = validationEnabled; 
    }

    public SignatureSubject build(){
            SignatureSubject buildable = new SignatureSubject(fluent.getCommonName(),fluent.getOrganization(),fluent.getPublicKeyID());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureSubjectBuilder that = (SignatureSubjectBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
